@@ -12,8 +12,8 @@
 module Text.Feed.Util where
 
 import Text.Feed.Types
-import Time
-import Locale
+import System.Time
+import System.Locale
 
 -- | 'toFeedDate' translates a calendar time into
 -- the format expected by the feed kind.
